RingSource

Struct RingSource 

pub struct RingSource<const TSHIRT_SIZE: usize, const RING_CAPACITY: usize> {
    pub writer: Writer<TSHIRT_SIZE, RING_CAPACITY>,
}
A Ring Source is the emitter bound to ring buffer Essentially has a writer that is used by underlying user - lets say an actor This can be leveraged to write to source which then can be read by others. RingBuffer is a shared entity, expected to be static, However it is expected that we follow Single Writer and many readers principle, Source emits events (See PooledEvent<TSHIRT_SIZE> for more details).

Fields

writer: Writer<TSHIRT_SIZE, RING_CAPACITY>

Implementations

Source

impl<const TSHIRT_SIZE: usize, const RING_CAPACITY: usize> RingSource<TSHIRT_SIZE, RING_CAPACITY>

pub fn new(out_buffer: &'static RingBuffer<TSHIRT_SIZE, RING_CAPACITY>) -> Self